@@ -8,6 +8,8 @@ import torch.nn.utils.rnn as rnn
 import torchaudio  # type: ignore
 from torch.utils.data import Dataset
 
+from timething import align, utils
+
 
 @dataclass
 class CSVRecord:
@@ -40,19 +42,33 @@ class Recording:
     # corresponding transcript
     transcript: str
 
+    # the alignment for this recording, if present on disk
+    alignment: typing.Optional[align.Alignment]
+
     # recording sample rate
     sample_rate: int
 
+    @property
+    def duration_seconds(self):
+        return self.audio.shape[-1] / self.sample_rate
+
 
 class SpeechDataset(Dataset):
     """
     Process a folder of audio files and transcriptions
     """
 
-    def __init__(self, metadata: Path, resample_to: int, clean_text_fn=None):
+    def __init__(
+        self,
+        metadata: Path,
+        resample_to: int,
+        alignments_path: typing.Optional[Path] = None,
+        clean_text_fn=None,
+    ):
         self.resample_to = resample_to
         self.clean_text_fn = clean_text_fn
         self.records = self.csv(metadata)
+        self.alignments_path = alignments_path
 
     def __getitem__(self, idx):
         """
@@ -65,16 +81,30 @@ class SpeechDataset(Dataset):
 
         # read in audio
         audio, sample_rate = torchaudio.load(record.file)
+
+        # resample, if needed
         if self.resample(sample_rate):
             tf = torchaudio.transforms.Resample(sample_rate, self.resample_to)
             audio = tf(audio)
 
+        # squash to or retain mono
+        audio = torch.mean(audio, 0, keepdim=True)
+
         # read and process transcription
         transcript = record.transcript
         if self.clean_text_fn:
             transcript = self.clean_text_fn(transcript)
 
-        return Recording(record.id, audio, transcript, sample_rate)
+        # read in aligments if they exist on disk
+        alignment = None
+        if self.alignments_path:
+            path = utils.alignment_filename(self.alignments_path, record.id)
+            if path.exists():
+                alignment = utils.read_alignment(
+                    self.alignments_path, alignment_id=record.id
+                )
+
+        return Recording(record.id, audio, transcript, alignment, sample_rate)
 
     def __len__(self):
         "number of examples in this dataset"
@@ -89,7 +119,7 @@ class SpeechDataset(Dataset):
         df = pd.read_csv(metadata, delimiter="|", names=("id", "transcript"))
         records = []
         for (_, row) in df.iterrows():
-            file_path = (metadata.parent / "wavs" / row.id).with_suffix(".wav")
+            file_path = metadata.parent / row.id
             records.append(CSVRecord(row.id, file_path, row.transcript))
 
         return records
